Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2461)

Unified Diff: base/win/win_util.h

Issue 10617002: Use a better registration suffix that will always be unique while respecting the MSDN rules. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/win/win_util.cc » ('j') | base/win/win_util.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/win/win_util.h
diff --git a/base/win/win_util.h b/base/win/win_util.h
index e831cd7450f8f1cd13edcea988158da8f9b8e4eb..a3978d5c799f3f99674a9f056c987947e1b11e62 100644
--- a/base/win/win_util.h
+++ b/base/win/win_util.h
@@ -47,9 +47,15 @@ const int kReflectedMessage = WM_APP + 3;
BASE_EXPORT void GetNonClientMetrics(NONCLIENTMETRICS* metrics);
// Returns the string representing the current user sid.
BASE_EXPORT bool GetUserSidString(std::wstring* user_sid);
+// Sets |user_sid| to a base 16 encoding (using A-N range) of the current user's
+// sid. This will fit in exactly 24 characters.
+// Returns true on success.
+BASE_EXPORT bool GetUserSidBase16Encoded(string16* user_sid);
gab 2012/06/21 05:55:41 Maybe this doesn't belong here idk...
+
// Returns true if the shift key is currently pressed.
BASE_EXPORT bool IsShiftPressed();
« no previous file with comments | « no previous file | base/win/win_util.cc » ('j') | base/win/win_util.cc » ('J')
@@ -47,9 +47,15 @@ const int kReflectedMessage = WM_APP + 3;
BASE_EXPORT void GetNonClientMetrics(NONCLIENTMETRICS* metrics);
-// Returns the string representing the current user sid.
+// Sets |user_sid| to the current user's sid.
+// Returns true on success.
BASE_EXPORT bool GetUserSidString(std::wstring* user_sid);

Powered by Google App Engine
This is Rietveld 408576698